@@ -41,7 +41,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.2'; # VERSION
+our $VERSION = 'v0.8.3'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -350,10 +350,10 @@ sub configure {
         } ],
 
         [ 'Hook::Init' => 'my vars' => {
-            'hook' => [ q{
-                pack} . q{age MY {          # Hide declaration from `new-version.t`.
+            'hook' => [ q[
+                { pack] . q[age MY;     # Hide declaration from `new-version.t`.
                     our $name           = $dist->name;
-                    our $package        = $name =~ s{-}{::}gr;
+                    ( our $package      = $name ) =~ s{-}{::}g;
                     our $version        = $dist->version;
                     our $Abstract       = $dist->abstract;
                     our $abstract       = lcfirst( $Abstract );
@@ -371,7 +371,7 @@ sub configure {
                     our $bundle         = $Dist::Zilla::PluginBundle::Author::VDB::Self;
                 };
                 $ENV{ 'TEST_FIX' . 'ME_FORMAT' } = 'perl';      # Hide keyword from `fixme.t`.
-            } ],
+            ] ],
         } ],
 
         #
@@ -389,9 +389,12 @@ sub configure {
                 'filename' => 'COPYING',
                 'content'  => [
                     q[{] . q[{],
-                    q[    include( MY::file( $plugin, ] . $self->_quote( $self->copying ) . q[ ) )],
-                    q[        ->fill_in],
-                    q[        ->pod2text( width => 80, indent => 0, loose => 1, quotes => 'none' );],
+                    q[    include( MY::file( $plugin, ] . $self->_quote( $self->copying ) . q[ ) )  ],
+                    q[        ->fill_in                                                             ],
+                    q[        ->pod2text( width => 80, indent => 0, loose => 1, quotes => 'none' )  ],
+                    q[        ->chomp;                                                              ],
+                    #   Resulting file may have one or two empty lines at the end, it affects
+                    #   testing. Let's try to chomp empty lines to avoid it.
                     q[}] . q[}],
                 ],
             } ],
@@ -403,11 +406,14 @@ sub configure {
                 'filename' => 'README',
                 'content'  => [
                     q[{] . q[{],
-                    q[    for my $file ( ] . $self->_quote( $self->readme ) . q[ ) {],
-                    q[        $OUT .= include( MY::file( $plugin, $file ) )],
-                    q[            ->fill_in],
-                    q[            ->pod2text( width => 80, indent => 0, loose => 1, quotes => 'none' );],
-                    q[    };],
+                    q[    for my $file ( ] . $self->_quote( $self->readme ) . q[ ) {                       ],
+                    q[        $OUT .=                                                                      ],
+                    q[            include( MY::file( $plugin, $file ) )                                    ],
+                    q[                ->fill_in                                                            ],
+                    q[                ->pod2text( width => 80, indent => 0, loose => 1, quotes => 'none' ) ],
+                    q[                ->chomp .                                                            ],
+                    q[            "\n\n";                                                                  ],
+                    q[    };                                                                               ],
                     q[}] . q[}],
                 ],
             } ],
@@ -926,7 +932,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.2, released on 2015-09-26 11:17 UTC.
+Version v0.8.3, released on 2015-09-27 01:12 UTC.
 
 =head1 WHAT?
 
